"""Sabermetrics: A python package with a set of baseball analytic functions for sabermetric purposes.

.. moduleauthor:: Fernando Crema <fcremaldc@gmail.com>

"""

import sabermetrics.pitching
import sabermetrics.fielding
import sabermetrics.batting


def start():
    "Initializing modules."
