from distutils.core import setup
setup(
  name = 'sabermetrics',
  packages = ['sabermetrics'], 
  version = '0.1',
  description = 'Beta version of the Sabermetrics Package: A python package with a set of baseball analytic functions for sabermetric purposes.',
  author = 'Fernando Crema',
  author_email = 'fcremaldc@gmail.com',
  url = 'https://github.com/belgrades/sabermetrics', 
  download_url = 'https://github.com/belgrades/sabermetrics/tarball/0.1', 
  keywords = ['beta', 'sabermetrics', 'baseball', 'MLB'], 
  classifiers = [],
)
